f64_full

Function f64_full 

pub fn f64_full(bits: impl FnMut() -> u64) -> f64
Returns a random f64 distributed as a uniform real in [0 . . 1) rounded down to the nearest representable value: every float in [0 . . 1) is reachable, subnormals and 0 included, with probability equal to the measure of the reals that round down to it.

A port of Float64full: as f64_117, except that zero words keep the zoom going, 64 binades at a time, down to the bottom of the subnormals.