Module sources

Module sources 

Trivial deterministic 64-bit generator.

Weyl is not a recommended general-purpose generator: it has insufficient statistical quality for anything but feeding a benchmark or a test. It is here so that all conversion techniques can be driven by the same cheap, inlinable bit stream.

Structs

Weyl
A Weyl (additive) generator: the state advances by the golden-ratio constant 0x9E3779B97F4A7C15 and is returned as is.